/*
 * Copyright (c) 2002-2019, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.example.service;

import fr.paris.lutece.plugins.example.business.Project;
import fr.paris.lutece.plugins.example.business.ProjectHome;
import fr.paris.lutece.portal.service.cache.AbstractCacheableService;
import fr.paris.lutece.portal.service.security.LuteceUser;

public class ProjectCacheService extends AbstractCacheableService
{
    private static final String SERVICE_NAME = "Project Example Cache Service";
    private static ProjectCacheService _instance = new ProjectCacheService( );

    public ProjectCacheService( )
    {
        initCache( );
    }

    public static ProjectCacheService getInstance( )
    {
        return _instance;
    }

    public String getName( )
    {
        return SERVICE_NAME;
    }

    public Project getResource( String strId, LuteceUser user )
    {
        Project ressource = (Project) getFromCache( strId );
        String cacheKey = getCacheKey( strId, user );

        if ( ressource == null )
        {
            // r = getResourceFromSource( strId );
            // putInCache( strId , r );
            ressource = ProjectHome.findByPrimaryKey( Integer.parseInt( strId ) );
            cacheKey = getCacheKey( String.valueOf( ressource.getId( ) ), user );
            putInCache( cacheKey, ressource );

        }
        return ressource;
    }

    private static String getCacheKey( String strId, LuteceUser user )
    {
        StringBuilder sbKey = new StringBuilder( );
        sbKey.append( "[project:" ).append( strId ).append( "][user:" );
        if ( user != null )
        {
            sbKey.append( user.getName( ) );
        }
        else
        {
            sbKey.append( "notLogged" );
        }
        sbKey.append( "]" );
        return sbKey.toString( );
    }
}
